@@ -1,17 +1,3 @@
-# parameter variation definitions
-# link namelist input with shortened version in modelTag
-parVariationDef <- c(ann = "annual",
-                     har = "harmonic",
-                     seas = "seasonal")
-
-# There are multiple harmonic models - define the harmonic tags for each variable
-# this is required to create the modelTag from namelist
-# Anjana: this can be eliminated once all the modelTags for "Temp", "PET", and "Radn" are all updated to be "har" instead of "har26"
-# harDefinition <- c(P = "har",
-#                    Temp = "har26",
-#                    PET = "har26",
-#                    Radn = "har26")
-
 # TO DO: add an argument 'compatibleAtts' (default FALSE)
 # if set to 'TRUE' all attributes of the variable will be shown in the printed data.frame
 # - with T/F to indicate if the attribute is compatible to use with the model
@@ -33,40 +19,40 @@ parVariationDef <- c(ann = "annual",
 #' viewModels("PET")
 #' @export
 viewModels <- function(variable = NULL) {
-
-  # vector of stochastic model tags - exclude scaling
-  stochModels <- modelTaglist[!(modelTaglist%in%c("Simple-ann","Simple-seas"))]
+  stochModels <- get_modelTags(modelInfoList = modelInfoList)
+  exclude <- c("Simple-ann", "Simple-seas")
+  stochModels <- stochModels[!stochModels %in% exclude]
 
   # get stochastic model Info
   varNames <- sapply(strsplit(stochModels, "-"), `[[`, 1)
   parVariation <- sapply(strsplit(stochModels, "-"), `[[`, 2)
   modelType <- sapply(strsplit(stochModels, "-"), `[[`, 3)
 
-  # check if the model has additional info
-  tagLength <- sapply(strsplit(stochModels, "-"), length)
-  for (m in 1:length(modelType)){
-    if (tagLength[m] > 3) {
-      for (i in 4:tagLength[m]) {
-        modelType[m] <- paste0(modelType[m], "-", strsplit(stochModels[m], "-")[[1]][i])
-      }
+  modelTimeStep <- c()
+  for (i in 1:length(stochModels)) {
+    stochModel <- stochModels[i]
+    mts <- modelInfoList[[stochModel]]$timeStep
+    if (length(mts) < 1) {
+      stop(paste0("require timeStep for model ", stochModel))
+    } else {
+      modelTimeStep[i] <- mts
     }
   }
-  modelTimeStep <- modelTimeStep[stochModels]
   defaultModel <- rep(FALSE, length(stochModels))
   defaultModel[which(stochModels %in% defaultModelTags)] <- TRUE
 
-  if(is.null(variable) || !(variable %in% varNames)) {
+  if (is.null(variable) || !(variable %in% varNames)) {
     print("Please select a valid variable. The valid variable names are:")
     print(unique(varNames))
   } else {
     # get index
     ind <- which(varNames == variable)
-    modelTimeStep <- modelTimeStep[ind]   # subsetted ind here so that the column would be named modelTimeStep in the data.frame output by the function
-    defaultModel <- defaultModel[ind]
 
     # model information dataframe
-    varModels <- data.frame(modelType[ind], parVariationDef[parVariation[ind]], modelTimeStep, defaultModel)
+    varModels <- data.frame(modelType[ind], parVariation[ind], modelTimeStep[ind], defaultModel[ind])
     colnames(varModels)[1:2] <- mdlFields
+    colnames(varModels)[3] <- "timeStep"
+    colnames(varModels)[4] <- "default"
     rownames(varModels) <- NULL
 
     return(varModels)
@@ -77,8 +63,9 @@ viewModels <- function(variable = NULL) {
 getModelSpec <- function(colName, var = NULL) {
   modelSpec <- NULL
 
+  fSVars <- get_fSVars(get_modelTags(modelInfoList = modelInfoList))
   # If variable is not specified - return data for all variables
-  if(is.null(var)){
+  if (is.null(var)) {
     var <- fSVars
   }
   for (v in var) {
@@ -102,22 +89,23 @@ getModelSpec <- function(colName, var = NULL) {
 
 
 # Model definifition fields of the namelist
-#======================================================================================
+# ======================================================================================
 # These are the columns used to define a model - printed using output of viewModels()
 # The possible values of these fields should always be a string/number (i.e., not a vector)
-mdlFields <- c("modelType", "modelParameterVariation") #NOTE: Both modelType & modelParameterVariation have to be specified
+mdlFields <- c("modelType", "modelParameterVariation") # NOTE: Both modelType & modelParameterVariation have to be specified
 
 mdlBounds <- c("modelParameterBounds")
 
-spatialOps = c("spatialOptions")
+ppOps <- c("postProcessing")
+
+spatialOps <- c("spatialOptions")
 
 # Optimization fields - can be specified independent of - mdlFields & mdlBounds
-#=======================================================================================
+# =======================================================================================
 optFields <- c("optimisationArguments", "penaltyAttributes", "penaltyWeights")
 
 # Function to return the masterNamelist options used to check controlFile
-getNamelistMaster <- function(){
-
+getNamelistMaster <- function() {
   outList <- list()
   for (f in mdlFields) {
     outList[[f]] <- getModelSpec(f)
@@ -125,12 +113,15 @@ getNamelistMaster <- function(){
   for (f in mdlBounds) {
     outList[[f]] <- list()
   }
+  for (f in ppOps) {
+    outList[[f]] <- list()
+  }
   for (f in spatialOps) {
     outList[[f]] <- list()
   }
   for (f in optFields) {
     if (f == "optimisationArguments") {
-      outList[[f]] <- names(optimArgsdefault)[!(names(optimArgsdefault)=="lambda.mult")]
+      outList[[f]] <- names(optimArgsdefault)[!(names(optimArgsdefault) == "lambda.mult")]
     } else {
       outList[[f]] <- list()
     }
@@ -140,7 +131,7 @@ getNamelistMaster <- function(){
 
 # Function to read controlFile. Will be used in generateScenario
 readNamelist <- function(jsonfile) {
-  if(!file.exists(jsonfile)) {
+  if (!file.exists(jsonfile)) {
     stop("controlFile json file does not exist")
   }
   nml <- jsonlite::fromJSON(txt = jsonfile)
@@ -150,7 +141,6 @@ readNamelist <- function(jsonfile) {
 
 # Function to get the user model choice of "v" from namelist, input is a list - read in from the namelist json file
 getModelChoice <- function(nml, v) {
-
   # initialize modelChoice
   modelChoice <- viewModels(v)[FALSE, 1:2]
   modelChoice[1, ] <- NA
@@ -178,16 +168,7 @@ getModelTag <- function(nml, v) {
     # use default
     modelTag <- defaultModelTags[[v]]
   } else {
-    # create from nml specifications
-    parTagLong <- modelChoice[["modelParameterVariation"]]
-
-    # Get the harmonic part of the modelTag based on the variable
-    if(parTagLong == "harmonic") {
-      parTag <- 'har'
-    } else {
-      parTag <- names(parVariationDef[parVariationDef == parTagLong])
-    }
-
+    parTag <- modelChoice[["modelParameterVariation"]]
     modelType <- modelChoice[["modelType"]]
     modelTag <- paste(c(v, parTag, modelType), collapse = "-")
   }
@@ -197,38 +178,35 @@ getModelTag <- function(nml, v) {
 # To create the original 'modelInfoMod' list based on the nml input
 # 'modelInfoMod' depends only on the vars specified as fields of mdlBounds
 getModelInfoMod <- function(nml) {
-
   field <- "modelParameterBounds"
-  if(!is.null(nml[[field]])) {
+  if (!is.null(nml[[field]])) {
     vars <- names(nml[[field]])
 
     modelInfoMod <- NULL
-    for (v in vars){
+    for (v in vars) {
       modelTag <- getModelTag(nml, v)
       modelInfoMod[[modelTag]] <- modifyParBounds(nml, v)
     }
     return(modelInfoMod)
   } else {
-    #cat(paste0("\ncontrolFile does not contain ", field, ". Using foreSIGHT defaults.\n"))
+    # cat(paste0("\ncontrolFile does not contain ", field, ". Using foreSIGHT defaults.\n"))
     return(list())
   }
-
 }
 
 getOptimArgs <- function(nml) {
-
   field1 <- "optimisationArguments"
   field2 <- "penaltyWeights"
 
   optimArgs <- list()
 
-  if(!is.null(nml[[field1]])) {
+  if (!is.null(nml[[field1]])) {
     optimArgs <- nml[[field1]]
   } else {
-    #cat(paste0("\ncontrolFile does not contain ", field1, ". Using foreSIGHT defaults.\n"))
+    # cat(paste0("\ncontrolFile does not contain ", field1, ". Using foreSIGHT defaults.\n"))
   }
 
-  if(!is.null(nml[[field2]])) {
+  if (!is.null(nml[[field2]])) {
     optimArgs[["lambda.mult"]] <- nml[[field2]]
   }
 
@@ -236,28 +214,31 @@ getOptimArgs <- function(nml) {
 }
 
 getAttPenalty <- function(nml) {
-
   field <- "penaltyAttributes"
   return(nml[[field]])
-
 }
 
 # remove arguments for other optimizers that are not used
-cleanOptimArgs = function(optimArgs){
-
-  if(optimArgs$optimizer!='RGN'){optimArgs$RGN.control=NULL}
-  if(optimArgs$optimizer!='SCE'){optimArgs$SCE.control=NULL}
-  if(optimArgs$optimizer!='CMAES'){optimArgs$CMAES.control=NULL}
-  if(optimArgs$optimizer!='NM'){optimArgs$NM.control=NULL}
-  if(optimArgs$optimizer!='GA'){optimArgs$GA.args=NULL}
+cleanOptimArgs <- function(optimArgs) {
+  if (optimArgs$optimizer != "RGN") {
+    optimArgs$RGN.control <- NULL
+  }
+  if (optimArgs$optimizer != "SCE") {
+    optimArgs$SCE.control <- NULL
+  }
+  # if(optimArgs$optimizer!='CMAES'){optimArgs$CMAES.control=NULL}
+  if (optimArgs$optimizer != "NM") {
+    optimArgs$NM.control <- NULL
+  }
+  if (optimArgs$optimizer != "GA") {
+    optimArgs$GA.args <- NULL
+  }
 
   return(optimArgs)
-
 }
 
 # Given a namelist & variable, return integrated (modelInfo + new bounds) minimum and maximum bounds in a list
 modifyParBounds <- function(nml, v) {
-
   field <- "modelParameterBounds"
   boundsIn <- nml[[field]][[v]]
   parsIn <- names(boundsIn)
@@ -273,8 +254,10 @@ modifyParBounds <- function(nml, v) {
     maxBound[ind] <- boundsIn[[p]][2]
   }
 
-  return(list(minBound = minBound,
-              maxBound = maxBound))
+  return(list(
+    minBound = minBound,
+    maxBound = maxBound
+  ))
 }
 
 
@@ -341,7 +324,6 @@ modifyParBounds <- function(nml, v) {
 #' }
 #' @export
 writeControlFile <- function(jsonfile = "sample_controlFile.json", basic = TRUE, nml = NULL) {
-
   # get defaults
   if (is.null(nml)) {
     modelTag <- defaultModelTags
@@ -355,15 +337,14 @@ writeControlFile <- function(jsonfile = "sample_controlFile.json", basic = TRUE,
     checkControlFile(nml)
   }
 
-  if(basic) {
+  if (basic) {
     nml[[mdlBounds]] <- NULL
-    nml[["optimisationArguments"]] <- NULL  # removed optimArgs from basic controlFile; add if needed
+    nml[["optimisationArguments"]] <- NULL # removed optimArgs from basic controlFile; add if needed
   }
   json_nml <- jsonlite::toJSON(nml, pretty = TRUE, auto_unbox = TRUE)
   write(json_nml, file = jsonfile)
 
   return(invisible())
-
 }
 
 # Function to create a namelist from a number of foreSIGHT options
@@ -374,8 +355,7 @@ writeControlFile <- function(jsonfile = "sample_controlFile.json", basic = TRUE,
 # 3. penaltyAtt - input namelist
 # 4. modelInfo - input namelist bounds + exisiting default bounds for unspecified parameters
 # The output is of type list - it can be passed to a writeNamelist function to write a json file
-toNamelist <- function(modelTag, modelInfoMod = NULL, optimArgs = NULL, attPenalty = NULL) {
-
+toNamelist <- function(modelTag, modelInfoMod = NULL, optimArgs = NULL, attPenalty = NULL, ppArgs = NULL) {
   if (!is.null(attPenalty)) penaltyWeights <- optimArgs[["lambda.mult"]]
   optimArgs[["lambda.mult"]] <- NULL
 
@@ -383,11 +363,8 @@ toNamelist <- function(modelTag, modelInfoMod = NULL, optimArgs = NULL, attPenal
   #----------------------------------------------------
   varNames <- sapply(strsplit(modelTag, "-"), `[[`, 1)
   parTag <- sapply(strsplit(modelTag, "-"), `[[`, 2)
-  parVar <- rep(NA, length(parTag))
-  for (i in 1:length(parTag)) {
-    parVar[i] <- parVariationDef[[parTag[i]]]
-  }
 
+  parVar <- parTag
   # modelType
   #----------------------------------------------------
   mType <- sapply(strsplit(modelTag, "-"), `[[`, 3)
@@ -426,6 +403,7 @@ toNamelist <- function(modelTag, modelInfoMod = NULL, optimArgs = NULL, attPenal
   nml[["modelType"]] <- modelType
   nml[["modelParameterVariation"]] <- modelParametervariation
   nml[["modelParameterBounds"]] <- modelParameterBounds
+  nml[["ppArgs"]] <- ppArgs
   if (!is.null(optimArgs) & !is.null(names(optimArgs))) {
     nml[["optimisationArguments"]] <- optimArgs
     for (n in names(optimArgs)) {
@@ -434,18 +412,16 @@ toNamelist <- function(modelTag, modelInfoMod = NULL, optimArgs = NULL, attPenal
       }
     }
   }
-  if(!is.null(attPenalty)) {
+  if (!is.null(attPenalty)) {
     nml[["penaltyAttributes"]] <- attPenalty
     nml[["penaltyWeights"]] <- penaltyWeights
   }
   return(nml)
-
 }
 
 # Internal function to get the parameters and their bounds using modelInfo and modelTag
 # Used to get information to write namelist out
 getModelParBounds <- function(modelTag, modelInfo = NULL) {
-
   varNames <- sapply(strsplit(modelTag, "-"), `[[`, 1)
 
   if (is.null(modelInfo)) {
@@ -458,16 +434,15 @@ getModelParBounds <- function(modelTag, modelInfo = NULL) {
   for (i in 1:length(modelTag)) {
     parNam <- modelInfo[[modelTag[i]]][["parNam"]]
 
-    parBounds <- matrix(rep(NA, length(parNam)*2), ncol = length(parNam))
+    parBounds <- matrix(rep(NA, length(parNam) * 2), ncol = length(parNam))
     parBounds[1, ] <- modelInfo[[modelTag[i]]][["minBound"]]
     parBounds[2, ] <- modelInfo[[modelTag[i]]][["maxBound"]]
 
     for (p in 1:length(parNam)) {
-      modelParameterBounds[[varNames[i]]][[parNam[p]]] <- parBounds[ ,p]
+      modelParameterBounds[[varNames[i]]][[parNam[p]]] <- parBounds[, p]
     }
   }
   return(modelParameterBounds)
-
 }
 
 # Function to view the parameter bounds of specific models - intended for user
@@ -495,7 +470,6 @@ getModelParBounds <- function(modelTag, modelInfo = NULL) {
 # Are the optimization argument fields valid (i.e., belongs to optimArgsdefault) (can add detailed checks later)
 
 checkControlFile <- function(nml) {
-
   # Master Namelist
   nmlMaster <- getNamelistMaster()
 
@@ -510,12 +484,12 @@ checkControlFile <- function(nml) {
   checkMdlFields(nml)
   checkOptFields(nml)
   checkMdlBounds(nml)
-
 }
 
 
 # check mdlFields
 checkMdlFields <- function(nml) {
+  fSVars <- get_fSVars(get_modelTags(modelInfoList = modelInfoList))
 
   # Master Namelist
   nmlMaster <- getNamelistMaster()
@@ -524,8 +498,8 @@ checkMdlFields <- function(nml) {
   for (field in mdlFields) {
     master <- nmlMaster[[field]]
     for (i in unlist(nml[[field]])) {
-      if(length(i) > 1 | !is.character(i)) stop(paste0("controlFile ", field, " input", i, " should be a string. Type viewModels() to view the valid options."))
-      if(!(i %in% master)) stop(paste0("controlFile ", field, " input", i, "unrecognized"))
+      if (length(i) > 1 | !is.character(i)) stop(paste0("controlFile ", field, " input", i, " should be a string. Type viewModels() to view the valid options."))
+      if (!(i %in% master)) stop(paste0("controlFile ", field, " input", i, "unrecognized"))
     }
   }
 
@@ -540,16 +514,18 @@ checkMdlFields <- function(nml) {
     for (v in varsi) {
       if (!(v %in% fSVars)) stop(paste0("controlFile variable", v, " specified in ", mdlFields[i], " is unrecognized. ", "Type viewModels() to view the valid variables"))
     }
-    if (!(all(vars1 %in% varsi) & all(varsi %in% vars1))) stop(paste0("Specify ", paste(mdlFields, collapse="/")," for every variable in controlFile"))
+    if (!(all(vars1 %in% varsi) & all(varsi %in% vars1))) stop(paste0("Specify ", paste(mdlFields, collapse = "/"), " for every variable in controlFile"))
   }
 
   # Check : combination of model choices are okay
   for (v in vars1) {
     modelChoice <- getModelChoice(nml, v)
     # compare with available options
-    if (nrow(merge(modelChoice, viewModels(v)[ ,1:2])) != 1) {
-      stop(paste0("controlFile: combination of ", paste(mdlFields, collapse = "/"), " specified for variable ", v, " is not valid. ",
-                  "Type viewModels(\"", v, "\") to view the valid options"))
+    if (nrow(merge(modelChoice, viewModels(v)[, 1:2])) != 1) {
+      stop(paste0(
+        "controlFile: combination of ", paste(mdlFields, collapse = "/"), " specified for variable ", v, " is not valid. ",
+        "Type viewModels(\"", v, "\") to view the valid options"
+      ))
     }
   }
   return(invisible())
@@ -560,11 +536,11 @@ checkMdlFields <- function(nml) {
 # This function needs to get modelTags from namelist if mdlFields are specified
 # Otherwise it needs to get modelTags from the defaults for each variable
 checkMdlBounds <- function(nml) {
-
   field <- mdlBounds
 
   vars <- names(nml[[field]])
   for (v in vars) {
+    fSVars <- get_fSVars(get_modelTags(modelInfoList = modelInfoList))
 
     if (!(v %in% fSVars)) stop(paste0("controlFile variable ", v, " specified in ", field, " is unrecognized. Type viewModels() to view the valid variables."))
 
@@ -573,10 +549,10 @@ checkMdlBounds <- function(nml) {
     parNam <- get.model.info(modelTag)[["parNam"]]
 
     for (p in parIn) {
-      if (!(p %in% parNam)) stop("controlFile parameter ", p,  " specified in ", field, " for variable ", v, " is unrecognized.")
+      if (!(p %in% parNam)) stop("controlFile parameter ", p, " specified in ", field, " for variable ", v, " is unrecognized.")
       bounds <- nml[[field]][[v]][[p]]
       if (length(bounds) != 2) stop("controlFile parameter ", p, " specified in ", field, " for variable ", v, " should have minimum and maximum bounds.")
-      if(bounds[1] > bounds[2]) stop("controlFile parameter ", p, " specified in ", field, " for variable ", v, ": minimum bound is greater than maximum.")
+      if (bounds[1] > bounds[2]) stop("controlFile parameter ", p, " specified in ", field, " for variable ", v, ": minimum bound is greater than maximum.")
     }
   }
   return(invisible())
@@ -585,7 +561,6 @@ checkMdlBounds <- function(nml) {
 
 # check optFields
 checkOptFields <- function(nml) {
-
   # Check names of optimArgs
   field <- "optimisationArguments"
 
@@ -593,21 +568,16 @@ checkOptFields <- function(nml) {
   nmlMaster <- getNamelistMaster()
 
   namesIn <- names(nml)
-  if(field %in% namesIn) {
+  if (field %in% namesIn) {
     master <- nmlMaster[[field]]
     for (i in names(nml[[field]])) {
-      if(!(i %in% master)) stop(paste0("controlFile ", field, " input ", i, " unrecognized"))
+      if (!(i %in% master)) stop(paste0("controlFile ", field, " input ", i, " unrecognized"))
     }
   }
 
   # Check length of penaltyAtt
-  if(! (length(nml[["penaltyWeights"]]) == length(nml[["penaltyWeights"]]))) {
+  if (!(length(nml[["penaltyWeights"]]) == length(nml[["penaltyWeights"]]))) {
     stop("controlFile: specify penaltyWeights for all penaltyAttributes")
   }
   return(invisible())
 }
-
-
-
-
-
